#ifndef WIDGET_H
#define WIDGET_H

#include <QWidget>
#include <QGraphicsEllipseItem>

QT_BEGIN_NAMESPACE
namespace Ui {
class Widget;
}
QT_END_NAMESPACE

class Widget : public QWidget
{
    Q_OBJECT

public:
    Widget(QWidget *parent = nullptr);
    ~Widget();

public slots:
    void newXPosition(int);
    void newYPosition(int);

private:
    Ui::Widget *ui;
    // Mi QGraphicItem
    QGraphicsEllipseItem *circle;
};
#endif // WIDGET_H
